@@ -46,8 +46,8 @@ def loadJiraSettings(path: str, cli):
     if not settings["password"]:
         raise RuntimeError("You must specify the jira server password")
 
-    logging.info(f"Using JIRA server: {settings['jira_server']}")
-    logging.info(f"username: {settings['username']}")
+    logging.debug(f"Using JIRA server: {settings['jira_server']}")
+    logging.debug(f"username: {settings['username']}")
 
     credentials = {"username": settings["username"], "password": settings["password"]}
     if "credentials" not in settings:
@@ -183,7 +183,7 @@ class JiraTool:
     def connect(self):
         jiraOptions = {"server": self.jira_server}
         jiraBasicAuth = (self.username, self.password)
-        logging.info(
+        logging.debug(
             f"Creating connection to {self.jira_server} with user {self.username}"
         )
         self.connection = JIRA(options=jiraOptions, basic_auth=jiraBasicAuth)
@@ -213,7 +213,7 @@ class JiraTool:
         else:
             raise RuntimeError("You must specify a comment to add to the ticket")
 
-    def createTicket(self, issue_data: dict, strict=True):
+    def createTicket(self, issue_data: dict, priority: str = None, strict=True):
         """
         Create a JIRA ticket from a data dictionary
         """
@@ -239,6 +239,12 @@ class JiraTool:
                     f"You must specify all the mandatory issue fields: {required}"
                 )
 
+        if priority:
+            logging.debug(f"Setting ticket priority to {priority}")
+            priority_info = self.getPriorityDict()
+            priority_data = {"id": priority_info[priority]}
+            issue_data["priority"] = priority_data
+
         new_issue = self.connection.create_issue(fields=issue_data)
         return new_issue
 
@@ -284,6 +290,18 @@ class JiraTool:
                 f"{singleIssue.key} {singleIssue.fields.summary} {singleIssue.fields.reporter.displayName}"
             )
 
+    def getPriorityDict(self):
+        """
+        Returns a dictionary of all the priorities on a server and their IDs
+        """
+        raw_priorities = self.connection.priorities()
+        priority_data = {}
+
+        for priority in raw_priorities:
+            logging.debug(f"{priority.name} : {priority.id}")
+            priority_data[priority.name] = priority.id
+        return priority_data
+
     def getTicket(self, ticket: str):
         """
         Peel a ticket out of JIRA
@@ -318,11 +336,10 @@ class JiraTool:
             jql_str=f"project = {project}"
         ):
             tickets[singleIssue.key] = singleIssue
-            logging.info(f"{singleIssue.key} : {singleIssue}")
-            logging.info(f"{singleIssue.key} : fields {singleIssue.fields}")
-            # logging.debug(f'dir(singleIssue : {dir(singleIssue)}')
+            logging.debug(f"{singleIssue.key} : {singleIssue}")
+            logging.debug(f"{singleIssue.key} : fields {singleIssue.fields}")
             logging.debug(f"dumpObj(singleIssue : {dumpObject(singleIssue)}")
-            logging.info(" ")
+            logging.debug(" ")
         return tickets
 
     def transitionTicket(self, ticket: str, state: str, comment: str = None):
